@@ -38,5 +38,5 @@ default_config = {
 """
 nornir_defaults = {
     "core": {"num_workers": 20},
-    "inventory": {"plugin": "netnir.core.NornirInventory"},
+    "inventory": {"plugin": "netnir.core.inventory.NornirInventory"},
 }
